# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")
from . import BatchAttributes, ProgressEventArgs

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance

class AuditTrail(System.IDisposable):  # Class
    def __init__(
        self,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
    ) -> None: ...

    CmdNameEditReportMethod: str = ...  # static # readonly
    CmdNameGenerateMethodReport: str = ...  # static # readonly
    CmdNameGenerateReport: str = ...  # static # readonly
    CmdNameValidateUser: str = ...  # static # readonly

    BatchFilePath: str  # readonly
    IsLocked: bool  # readonly
    IsReadOnly: bool  # readonly
    IsTrailing: bool  # readonly

    def AfterNewBatch(self, error: bool) -> None: ...
    def BeforeSaveBatchAs(
        self, batchPath: str, batchFile: str, revisionNumber: str
    ) -> None: ...
    def Dispose(self) -> None: ...
    @staticmethod
    def GetLocalAuditFilePath(
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
        batchPath: str,
        batchFile: str,
        revisionNumber: str,
    ) -> str: ...
    def Lock(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet
    ): ...
    def Save(self, batchHashCode: str) -> None: ...
    def BeforeNewBatch(
        self, batchPath: str, batchFile: str, auditTrail: bool, deleteIfExists: bool
    ) -> None: ...
    def BeforeSaveBatch(self) -> None: ...
    def Unlock(self) -> None: ...
    def AfterSaveBatchAs(self, batchHashCode: str, error: bool) -> None: ...
    def AfterOpenBatch(self, error: bool) -> None: ...
    def BeforeCloseBatch(self) -> None: ...
    def AfterCloseBatch(self, error: bool) -> None: ...
    def AfterSaveBatch(self, batchHashCode: str, error: bool) -> None: ...
    def BeforeOpenBatch(
        self,
        batchPath: str,
        batchFile: str,
        revisionNumber: str,
        readOnly: bool,
        batchHashCode: str,
        schemaVersion: int,
    ) -> None: ...
    def AddEntry(
        self,
        command: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
        exception: System.Exception,
        reason: str,
    ) -> None: ...

class AuditTrailDataSet(
    System.IDisposable,
    System.ComponentModel.ISupportInitializeNotification,
    System.IServiceProvider,
    System.Data.DataSet,
    System.Xml.Serialization.IXmlSerializable,
    System.Runtime.Serialization.ISerializable,
    System.ComponentModel.IListSource,
    System.ComponentModel.ISupportInitialize,
    System.ComponentModel.IComponent,
):  # Class
    def __init__(self) -> None: ...

    Entry: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet.EntryDataTable
    )  # readonly
    Relations: System.Data.DataRelationCollection  # readonly
    SchemaSerializationMode: System.Data.SchemaSerializationMode
    Tables: System.Data.DataTableCollection  # readonly

    @staticmethod
    def GetTypedDataSetSchema(
        xs: System.Xml.Schema.XmlSchemaSet,
    ) -> System.Xml.Schema.XmlSchemaComplexType: ...
    def Clone(self) -> System.Data.DataSet: ...

    # Nested Types

    class EntryDataTable(
        System.ComponentModel.ISupportInitialize,
        Iterable[Any],
        System.ComponentModel.ISupportInitializeNotification,
        System.Xml.Serialization.IXmlSerializable,
        System.ComponentModel.IComponent,
        System.Runtime.Serialization.ISerializable,
        System.Data.TypedTableBase[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet.EntryRow
        ],
        Iterable[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet.EntryRow
        ],
        System.ComponentModel.IListSource,
        System.IDisposable,
        System.IServiceProvider,
    ):  # Class
        def __init__(self) -> None: ...

        ActionColumn: System.Data.DataColumn  # readonly
        CommentColumn: System.Data.DataColumn  # readonly
        Count: int  # readonly
        ExceptionColumn: System.Data.DataColumn  # readonly
        IDColumn: System.Data.DataColumn  # readonly
        InSessionColumn: System.Data.DataColumn  # readonly
        def __getitem__(
            self, index: int
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet.EntryRow
        ): ...
        MessageColumn: System.Data.DataColumn  # readonly
        NameColumn: System.Data.DataColumn  # readonly
        ReasonColumn: System.Data.DataColumn  # readonly
        SucceededColumn: System.Data.DataColumn  # readonly
        TimeColumn: System.Data.DataColumn  # readonly
        UserColumn: System.Data.DataColumn  # readonly

        def RemoveEntryRow(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet.EntryRow,
        ) -> None: ...
        @staticmethod
        def GetTypedTableSchema(
            xs: System.Xml.Schema.XmlSchemaSet,
        ) -> System.Xml.Schema.XmlSchemaComplexType: ...
        @overload
        def AddEntryRow(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet.EntryRow,
        ) -> None: ...
        @overload
        def AddEntryRow(
            self,
            ID: int,
            Name: str,
            User: str,
            Time: System.DateTime,
            Action: str,
            Reason: str,
            Comment: str,
            Succeeded: bool,
            Message: str,
            Exception: str,
            InSession: bool,
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet.EntryRow
        ): ...
        def NewEntryRow(
            self,
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet.EntryRow
        ): ...
        def Clone(self) -> System.Data.DataTable: ...
        def FindByID(
            self, ID: int
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet.EntryRow
        ): ...

        EntryRowChanged: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet.EntryRowChangeEventHandler
        )  # Event
        EntryRowChanging: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet.EntryRowChangeEventHandler
        )  # Event
        EntryRowDeleted: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet.EntryRowChangeEventHandler
        )  # Event
        EntryRowDeleting: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet.EntryRowChangeEventHandler
        )  # Event

    class EntryRow(System.Data.DataRow):  # Class
        Action: str
        Comment: str
        Exception: str
        ID: int
        InSession: bool
        Message: str
        Name: str
        Reason: str
        Succeeded: bool
        Time: System.DateTime
        User: str

        def SetTimeNull(self) -> None: ...
        def IsExceptionNull(self) -> bool: ...
        def IsUserNull(self) -> bool: ...
        def SetUserNull(self) -> None: ...
        def SetCommentNull(self) -> None: ...
        def SetActionNull(self) -> None: ...
        def IsNameNull(self) -> bool: ...
        def IsSucceededNull(self) -> bool: ...
        def IsInSessionNull(self) -> bool: ...
        def IsCommentNull(self) -> bool: ...
        def SetInSessionNull(self) -> None: ...
        def SetSucceededNull(self) -> None: ...
        def IsMessageNull(self) -> bool: ...
        def SetNameNull(self) -> None: ...
        def IsTimeNull(self) -> bool: ...
        def SetExceptionNull(self) -> None: ...
        def SetMessageNull(self) -> None: ...
        def IsActionNull(self) -> bool: ...
        def IsReasonNull(self) -> bool: ...
        def SetReasonNull(self) -> None: ...

    class EntryRowChangeEvent(System.EventArgs):  # Class
        def __init__(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet.EntryRow,
            action: System.Data.DataRowAction,
        ) -> None: ...

        Action: System.Data.DataRowAction  # readonly
        Row: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet.EntryRow
        )  # readonly

    class EntryRowChangeEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, object: Any, method: System.IntPtr) -> None: ...
        def EndInvoke(self, result: System.IAsyncResult) -> None: ...
        def BeginInvoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet.EntryRowChangeEvent,
            callback: System.AsyncCallback,
            object: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet.EntryRowChangeEvent,
        ) -> None: ...

class AuditTrailException(
    System.Runtime.InteropServices._Exception,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ComplianceException,
    System.Runtime.Serialization.ISerializable,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, msg: str) -> None: ...
    @overload
    def __init__(self, msg: str, innerException: System.Exception) -> None: ...

class AuditTrailFile(System.IDisposable):  # Class
    BatchExtensionBin: str  # static
    BatchExtensionXml: str  # static
    FileExtention: str = ...  # static # readonly
    SsizipExtension: str  # static
    Tag_BatchHashCode: str = ...  # static # readonly
    Tag_HashCode: str = ...  # static # readonly
    Tag_Root: str = ...  # static # readonly
    Tag_Version: str = ...  # static # readonly

    def Dispose(self) -> None: ...
    def Load(
        self,
        stream: System.IO.Stream,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet,
        isInSession: bool,
    ) -> None: ...

class AuditTrailFileBase(System.IDisposable):  # Class
    def __init__(self) -> None: ...

    Tag_HashCode: str = ...  # static # readonly
    Tag_Root: str = ...  # static # readonly
    Tag_Version: str = ...  # static # readonly

    IsReadOnly: bool  # readonly
    IsTrailing: bool  # readonly

    def Create(self, pathName: str, deleteIfExists: bool) -> None: ...
    def Save(self, dataHashCodeTag: str, dataHashCode: str) -> None: ...
    def LoadInSessionEntriesTo(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet,
    ) -> None: ...
    def Open(
        self,
        pathName: str,
        isReadOnly: bool,
        dataHashCodeTag: str,
        dataHashCodeToCheck: str,
    ) -> None: ...
    def Clean(self) -> None: ...
    def LoadTo(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet,
    ) -> None: ...
    def SaveAs(
        self, pathName: str, dataHashCodeTag: str, dataHashCode: str
    ) -> None: ...
    def Dispose(self) -> None: ...
    def AddEntry(
        self,
        user: str,
        command: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
        exception: System.Exception,
        reason: str,
    ) -> None: ...

class Command:  # Class
    def __init__(self) -> None: ...

    Name: str
    PrivilegeID: int
    RequireReason: bool
    RequireUserValidation: bool
    Roles: List[str]

class CommandGroup:  # Class
    def __init__(self) -> None: ...

    Commands: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.Command
    ]
    Name: str

class CommandPermissionException(
    System.Runtime.InteropServices._Exception,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ComplianceException,
    System.Runtime.Serialization.ISerializable,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, msg: str) -> None: ...
    @overload
    def __init__(self, msg: str, innerException: System.Exception) -> None: ...

class CommandPrincipalBase(System.IDisposable):  # Class
    LogonRequired: bool  # readonly
    User: str  # readonly

    @overload
    def Logon(self, user: str, domain: str, pwd: str) -> None: ...
    @overload
    def Logon(
        self, user: str, domain: str, pwd: System.Security.SecureString
    ) -> None: ...
    def DuplicateFrom(
        self,
        pricipal: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.CommandPrincipalBase,
    ) -> None: ...
    def Copy(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.CommandPrincipalBase
    ): ...
    @overload
    def Validate(self, user: str, pwd: str) -> None: ...
    @overload
    def Validate(self, user: str, pwd: System.Security.SecureString) -> None: ...
    def IsInRole(self, role: str) -> bool: ...
    def Dispose(self) -> None: ...

class CommandWindowsPrincipal(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.CommandPrincipalBase,
):  # Class
    def __init__(self) -> None: ...

    LogonRequired: bool  # readonly
    User: str  # readonly

    @overload
    def Logon(
        self, user: str, domain: str, pwd: System.Security.SecureString
    ) -> None: ...
    @overload
    def Logon(self, user: str, domain: str, pwd: str) -> None: ...
    def DuplicateFrom(
        self,
        pricipal: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.CommandPrincipalBase,
    ) -> None: ...
    def Copy(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.CommandPrincipalBase
    ): ...
    def Impersonate(self) -> System.IDisposable: ...
    @overload
    def Validate(self, user: str, pwd: str) -> None: ...
    @overload
    def Validate(self, user: str, pwd: System.Security.SecureString) -> None: ...
    def IsInRole(self, role: str) -> bool: ...

class ComplianceConfiguration:  # Class
    def __init__(self) -> None: ...

    AlwaysAuditTrail: bool
    DateTime: System.DateTime
    Groups: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.CommandGroup
    ]
    LockApplication: bool
    LockApplicationInterval: int
    LogonRequired: bool
    Redirect: str
    Roles: List[str]
    User: str

    def CheckAndRecover(self) -> None: ...
    def DebugCheck(self) -> None: ...

class ComplianceConfigurationFile:  # Class
    DefaultFilePath: str  # static # readonly

    @overload
    @staticmethod
    def Load(
        path: str, checkHash: bool, recover: bool
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ComplianceConfiguration
    ): ...
    @overload
    @staticmethod
    def Load(
        stream: System.IO.Stream, checkHash: bool, recover: bool
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ComplianceConfiguration
    ): ...
    @staticmethod
    def MergeCommands(
        from_: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ComplianceConfiguration,
        to: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ComplianceConfiguration,
    ) -> None: ...
    @staticmethod
    def GetHiddenCommands() -> List[str]: ...
    @staticmethod
    def CreateDefault() -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ComplianceConfiguration
    ): ...
    @staticmethod
    def IsHiddenCommand(command: str) -> bool: ...
    @overload
    @staticmethod
    def Save(
        path: str,
        map: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ComplianceConfiguration,
    ) -> None: ...
    @overload
    @staticmethod
    def Save(
        stream: System.IO.Stream,
        map: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ComplianceConfiguration,
    ) -> None: ...

class ComplianceException(
    System.Security.SecurityException,
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, msg: str) -> None: ...
    @overload
    def __init__(self, msg: str, innerException: System.Exception) -> None: ...

class ComplianceFactory:  # Class
    IsInstalled: bool  # static # readonly

    @overload
    @staticmethod
    def CreateInstance(
        name: str,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance: ...
    @overload
    @staticmethod
    def CreateInstance() -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance
    ): ...
    @overload
    @staticmethod
    def CreateInstance(
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance: ...
    @staticmethod
    def Install(type: str) -> None: ...
    @staticmethod
    def GetActiveType() -> str: ...
    @staticmethod
    def GetLogonType() -> int: ...

class ComplianceUtils:  # Class
    @overload
    @staticmethod
    def IsBatchAuditTrail(
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
        batchPath: str,
        batchFile: str,
    ) -> bool: ...
    @overload
    @staticmethod
    def IsBatchAuditTrail(
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
        batchPath: str,
        batchFile: str,
        batchHashCode: str,
        schemaVersion: int,
    ) -> bool: ...
    @staticmethod
    def ToSecureString(str: str) -> System.Security.SecureString: ...
    @staticmethod
    def ReadBatchHeader(
        batchFilePath: str,
        schemaVersion: int,
        hashCode: str,
        isAuditTrail: bool,
        attrs: BatchAttributes,
    ) -> bool: ...
    @staticmethod
    def DecryptPassword(encrypted: str) -> System.Security.SecureString: ...

class FileInfo(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IFileInfo
):  # Class
    def __init__(self) -> None: ...

    DateCreated: Optional[System.DateTime]
    DateModified: Optional[System.DateTime]
    DateUploaded: Optional[System.DateTime]
    Name: str
    Path: str

class IAuditTrail(object):  # Interface
    AlwaysAuditTrail: bool  # readonly
    IsAuditTrailing: bool  # readonly
    IsReadOnly: bool  # readonly

    def AddEntry(
        self,
        command: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
        exception: System.Exception,
    ) -> None: ...
    def SaveAuditTrail(self) -> None: ...
    def UnlockAuditTrail(self) -> None: ...
    def LockAuditTrail(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet
    ): ...

class IBatchFileService(object):  # Interface
    DefaultDataFolder: str  # readonly

    def BeforeNewBatch(
        self, batchFolder: str, batchFile: str, auditTrail: bool
    ) -> None: ...
    def TranslateMethodToLocalPath(
        self, methodPath: str, revisionNumber: str
    ) -> str: ...
    def AfterNewBatch(self, error: bool) -> None: ...
    def AfterOpenBatch(self, error: bool) -> None: ...
    def UploadMethod(self, methodFile: str, revisionNumber: str) -> None: ...
    def CheckoutBatch(self, batchFolder: str, batchFile: str) -> None: ...
    def AfterSaveBatchAs(self, batchHashCode: str, hasError: bool) -> None: ...
    def BeforeClose(self) -> None: ...
    def PrepareLibrary(self, libraryPath: str, revisionNumber: str) -> None: ...
    def GetSampleFileNames(self, batchFolder: str) -> List[str]: ...
    def MethodExists(self, methodPath: str) -> bool: ...
    def BatchFileExists(self, batchFolder: str, batchFile: str) -> bool: ...
    def AfterSaveBatch(self, batchHashCode: str, hasError: bool) -> None: ...
    def UndoCheckoutBatch(self, batchFolder: str, batchFile: str) -> None: ...
    def BeforeOpenBatch(
        self, batchFolder: str, batchFile: str, readOnly: bool, revisionNumber: str
    ) -> None: ...
    def GetBatchFiles(self, folder: str) -> List[str]: ...
    def GetLatestMethodRevisionNumber(self, methodPath: str) -> str: ...
    def GetSampleInfo(self, samplePath: str) -> Dict[str, Any]: ...
    def LibraryExists(self, libratyPath: str) -> bool: ...
    def TranslateBatchToLocalPath(
        self, batchFilePath: str, revisionNumber: str
    ) -> str: ...
    def GetMethodHistory(
        self, methodPath: str
    ) -> Iterable[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IRevisionHistory
    ]: ...
    def BeforeSaveBatchAs(self, batchFolder: str, batchFile: str) -> None: ...
    def GetLatestLibraryRevisionNumber(self, libraryPath: str) -> str: ...
    def GetBatchFileInfos(
        self, folder: str
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IFileInfo
    ]: ...
    def IsMethodFolder(self, methodPath: str) -> bool: ...
    def AfterClose(self, hasError: bool) -> None: ...
    def UploadLibrary(self, libraryPath: str, revisionNumber: str) -> None: ...
    def IsBatchCheckedoutByCurrentUser(
        self, batchFolder: str, batchFile: str
    ) -> bool: ...
    def BeforeSaveBatch(self) -> None: ...
    def AfterCloseMethod(self, methodFile: str) -> None: ...
    def PrepareMethod(self, methodPath: str, revisionNumber: str) -> None: ...
    def SampleFileExists(self, samplePath: str) -> bool: ...
    def GetBatchFilePath(self, batchFolder: str, batchFile: str) -> str: ...
    def PrepareSamples(self, samplePathes: List[str]) -> None: ...
    def PrepareBatch(
        self, batchFolder: str, batchFile: str, progress: System.Action[int, int, str]
    ) -> None: ...
    def GetLatestBatchRevisionNumber(self, batchFolder: str, batchFile: str) -> str: ...

    Progress: System.EventHandler[ProgressEventArgs]  # Event

class ICommandPermission(object):  # Interface
    CommandReason: str
    IsInCommandGroup: bool  # readonly
    UserValidated: bool  # readonly
    UserValidationExecuted: bool

    def UserValidationRequiredCore(self, commandName: str) -> bool: ...
    @overload
    def CheckPreCommandCondition(
        self,
        command: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    ) -> None: ...
    @overload
    def CheckPreCommandCondition(self, commandName: str) -> None: ...
    def BeginCommandGroup(self) -> None: ...
    def CommandReasonRequiredCore(self, commandName: str) -> bool: ...
    @overload
    def DemandPermission(
        self,
        command: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    ) -> None: ...
    @overload
    def DemandPermission(self, commandName: str) -> None: ...
    def EndCommandGroup(self) -> None: ...
    def CommandReasonRequired(self, commandName: str) -> bool: ...
    @overload
    def HasPermission(
        self,
        command: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    ) -> bool: ...
    @overload
    def HasPermission(self, commandName: str) -> bool: ...
    def ValidateUser(
        self, user: str, password: System.Security.SecureString
    ) -> None: ...
    def UserValidationRequired(self, commandName: str) -> bool: ...

    CommandGroupEnded: System.EventHandler  # Event
    CommandGroupStarted: System.EventHandler  # Event

class ICompliance(System.IDisposable):  # Interface
    AuditTrail: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IAuditTrail
    )  # readonly
    BatchFileService: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IBatchFileService
    )  # readonly
    CommandPermission: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICommandPermission
    )  # readonly
    DataStorage: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IDataStorage
    )  # readonly
    DisplayName: str  # readonly
    IsActive: bool  # readonly
    IsLocal: bool  # readonly
    LogonInfo: str  # readonly
    LogonRequired: bool  # readonly
    Name: str  # readonly
    ReportFileService: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IReportFileService
    )  # readonly
    Server: str  # readonly
    UnknownsFileService: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IUnknownsFileService
    )  # readonly
    UserName: str  # readonly
    Version: str  # readonly

    def GetToken(self) -> str: ...
    def GetService(self) -> T: ...
    def Impersonate(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IImpersonationContext
    ): ...
    def CheckConnection(self) -> None: ...
    def CommandEnd(
        self,
        command: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    ) -> None: ...
    def InitQuantCommandPermission(self) -> None: ...
    def GetUI(self) -> T: ...
    def LogonXml(self, xml: str) -> None: ...
    @overload
    def Connect(
        self,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
    ) -> None: ...
    @overload
    def Connect(self, token: str) -> None: ...
    def ValidateUser(
        self, user: str, password: System.Security.SecureString
    ) -> None: ...
    def CommandStart(
        self,
        command: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    ) -> None: ...

class IComplianceCommand(object):  # Interface
    ActionString: str  # readonly
    Name: str  # readonly

class IComplianceCommandEx(object):  # Interface
    ActionStrings: List[str]  # readonly

class IComplianceLightCommand(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand
):  # Interface
    ...

class IDataStorage(System.IDisposable):  # Interface
    InitialRevisionNumber: str  # readonly
    IsRevisionSupported: bool  # readonly
    OpenFolderSupported: bool  # readonly
    PathSeparator: str  # readonly

    def GetLatestRevisionNumber(self, path: str) -> str: ...
    @overload
    def UploadFile(self, pathName: str) -> None: ...
    @overload
    def UploadFile(self, pathName: str, revisionNumber: str) -> None: ...
    def Combine(self, paths: List[str]) -> str: ...
    @overload
    def DownloadFile(self, pathName: str) -> None: ...
    @overload
    def DownloadFile(self, pathName: str, revisionNumber: str) -> None: ...
    def GetFiles(self, folder: str, searchPattern: str) -> List[str]: ...
    def GetFolderPathName(self, pathName: str) -> str: ...
    def GetFileName(self, pathName: str) -> str: ...
    def GetHistory(
        self, path: str
    ) -> Iterable[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IRevisionHistory
    ]: ...
    def GetNextRevisionNumber(self, path: str) -> str: ...
    @overload
    def TranslateToLocalPath(self, path: str) -> str: ...
    @overload
    def TranslateToLocalPath(self, path: str, revisionNumber: str) -> str: ...
    def FileExists(self, path: str) -> bool: ...
    def OpenFolder(self, folderPath: str) -> None: ...
    def FolderExists(self, path: str) -> bool: ...
    def GetFolders(self, folder: str, searchPattern: str) -> List[str]: ...

class IFileInfo(object):  # Interface
    DateCreated: Optional[System.DateTime]  # readonly
    DateModified: Optional[System.DateTime]  # readonly
    DateUploaded: Optional[System.DateTime]  # readonly
    Name: str  # readonly
    Path: str  # readonly

class IFolderInfo(object):  # Interface
    DateModifies: Optional[System.DateTime]  # readonly
    Name: str  # readonly
    Path: str  # readonly

class IImpersonationContext(System.IDisposable):  # Interface
    ...

class ILogonECM(object):  # Interface
    def Logon(
        self,
        server: str,
        domain: str,
        user: str,
        password: System.Security.SecureString,
        accountName: str,
    ) -> None: ...

class ILogonParameters(object):  # Interface
    AccountName: str  # readonly
    ConnectionTicket: str  # readonly
    Domain: str  # readonly
    Server: str  # readonly
    User: str  # readonly
    _Password: System.Security.SecureString  # readonly

class ILogonWindows(object):  # Interface
    def Logon(
        self, user: str, domain: str, password: System.Security.SecureString
    ) -> None: ...

class IPrincipal(object):  # Interface
    def IsInRole(self, role: str) -> bool: ...

class IReportCompliance(object):  # Interface
    Reporting: bool

class IReportFileService(object):  # Interface
    def DownloadFolderToWorkArea(self, path: str) -> None: ...
    def OpenFile(self, path: str) -> None: ...
    def DownloadFileToWorkArea(self, path: str) -> None: ...
    def UploadFileFromWorkArea(self, path: str) -> None: ...
    def GetDefaultOutputFolder(self, batchFolder: str, batchFile: str) -> str: ...
    def Print(self, path: str, printer: str) -> None: ...
    def TranslateToWorkPath(self, path: str) -> str: ...
    def DownloadFileAndUnzipToWorkArea(self, path: str) -> None: ...

class IRevisionHistory(object):  # Interface
    Date: Optional[System.DateTime]  # readonly
    Reason: str  # readonly
    RevisionNumber: str  # readonly
    User: str  # readonly

class IUnknownsFileService(object):  # Interface
    def GetAnalysisFilePath(self, batchFolder: str, analysisFile: str) -> str: ...
    def GetLatestAnalysisRevision(self, batchFolder: str, analysisFile: str) -> str: ...
    def AnalysisFileExists(self, batchFolder: str, analysisFile: str) -> bool: ...
    def TranslateAnalysisToLocalPath(self, path: str, revisionNumber: str) -> str: ...
    def DownloadAnalysisFile(
        self, batchFolder: str, analysisFile: str, revisionNumber: str
    ) -> None: ...
    def CheckoutAnalysis(self, batchFolder: str, batchFile: str) -> None: ...
    def GetAnalysisFileInfos(
        self, folder: str
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IFileInfo
    ]: ...
    def UploadAnalysisFile(
        self, batchFolder: str, analysisFile: str, revisionNumber: str
    ) -> None: ...
    def UndoCheckoutAnalysis(self, batchFolder: str, batchFile: str) -> None: ...
    def IsAnalysisCheckedoutByCurrentUser(
        self, batchFolder: str, batchFile: str
    ) -> bool: ...
    def GetAnalysisFiles(self, folder: str) -> List[str]: ...

class LogonUtils:  # Class
    @staticmethod
    def InlineLogon(
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
        parameters: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ILogonParameters,
    ) -> None: ...
    @staticmethod
    def EncryptPassword(password: str) -> str: ...
    @staticmethod
    def DecryptPassword(encrypted: str) -> System.Security.SecureString: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import ILibrary, LibraryDataSet
from .MFS import MolecularFormula

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Exactify

class AmbiguousPeakResolutionForm(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(
        self,
        peakMapRecord: Agilent.MassSpectrometry.DataAnalysis.Exactify.SpectrumPeakMappingRecord,
    ) -> None: ...

    IsPeakDeleted: bool  # readonly
    IsSelectionModified: bool  # readonly
    SelectedCharge: int  # readonly
    SelectedFragment: MolecularFormula  # readonly

class DefaultEventManipulator(
    Agilent.MassSpectrometry.EventManipulating.Model.IEventManipulator,
    System.IDisposable,
    Agilent.MassSpectrometry.GUI.Plot.DefaultEventManipulatorBase,
):  # Class
    def __init__(
        self, context: Agilent.MassSpectrometry.EventManipulating.EventContext
    ) -> None: ...
    def OnMouseUp(
        self, sender: Any, e: System.Windows.Forms.MouseEventArgs
    ) -> None: ...
    def OnMouseMove(
        self, sender: Any, e: System.Windows.Forms.MouseEventArgs
    ) -> None: ...

class DeletePeakDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(
        self, peak: Agilent.MassSpectrometry.DataAnalysis.Exactify.ExactMassIon
    ) -> None: ...

class ExactMassIon:  # Class
    Abundance: float  # readonly
    Charge: int  # readonly
    FragmentFinder: (
        Agilent.MassSpectrometry.DataAnalysis.Exactify.FragmentFindingAlgorithm
    )  # readonly
    IsAmbiguous: bool  # readonly
    MZ: float  # readonly
    MzDeltaPpm: float  # readonly
    ParentFormula: MolecularFormula  # readonly
    RelativeAbundance: float  # readonly
    SelectedFragment: MolecularFormula  # readonly
    SourceMz: float  # readonly

class Exactify:  # Class
    @overload
    def __init__(
        self,
        library: ILibrary,
        exParams: Agilent.MassSpectrometry.DataAnalysis.Exactify.ExactifyParams,
    ) -> None: ...
    @overload
    def __init__(self, library: ILibrary, sessionFilePath: str) -> None: ...

    ErrorMessage: str  # readonly
    ExactMassLibrary: ILibrary  # readonly
    ExactifyParams: (
        Agilent.MassSpectrometry.DataAnalysis.Exactify.ExactifyParams
    )  # readonly
    IsCancelled: bool  # readonly
    IsModified: bool  # readonly
    IsRestored: bool  # readonly
    NumSpectraProcessed: int  # readonly
    SourceLibrary: ILibrary  # readonly

    def SaveExactMassLibrary(self) -> None: ...
    def RunLibrary(self) -> None: ...
    def SaveSession(self, sessionFilePath: str) -> None: ...
    def GetSpectrumMappingRecord(
        self, spectrum: LibraryDataSet.SpectrumRow
    ) -> Agilent.MassSpectrometry.DataAnalysis.Exactify.SpectrumMappingRecord: ...
    def DeleteSpectrumPeak(
        self,
        peakMapRecord: Agilent.MassSpectrometry.DataAnalysis.Exactify.SpectrumPeakMappingRecord,
    ) -> bool: ...
    def GetMzUniquenessCount(self, mz: float) -> int: ...
    def SetSelectedFragment(
        self,
        peakMapRecord: Agilent.MassSpectrometry.DataAnalysis.Exactify.SpectrumPeakMappingRecord,
        selectedFragment: MolecularFormula,
        charge: int,
    ) -> bool: ...
    def CleanUp(self) -> None: ...
    def RestoreSession(self, sessionFilePath: str) -> None: ...
    def RunSpectrum(self, spectrumIndex: int) -> None: ...
    def IsExactSpectrumModified(self, spectrumIndex: int) -> bool: ...
    def RunNewCompounds(self) -> None: ...
    def RestoreDeletedPeak(
        self,
        peakMapRecord: Agilent.MassSpectrometry.DataAnalysis.Exactify.SpectrumPeakMappingRecord,
    ) -> bool: ...
    def Cancel(self) -> None: ...

    LibraryProcessed: (
        Agilent.MassSpectrometry.DataAnalysis.Exactify.LibraryProcessedEventHandler
    )  # Event
    SpectrumProcessed: (
        Agilent.MassSpectrometry.DataAnalysis.Exactify.SpectrumProcessedEventHandler
    )  # Event

class ExactifyLog:  # Class
    @staticmethod
    def GetCompoundName(compound: LibraryDataSet.CompoundRow) -> str: ...

class ExactifyParams:  # Class
    def __init__(self) -> None: ...

    AllowMultiplyChargedIons: bool
    DisableLogging: bool
    KeepAmbiguouslyMappedIons: bool
    LogFilePath: str
    MaxIonsPerSpectrum: int
    MinMzDelta: float
    MinRelativeAbundance: float
    MzDeltaPpm: float
    OutputLibraryPath: str
    UseChemSpider: bool
    Weighting: Agilent.MassSpectrometry.DataAnalysis.Exactify.SpectrumPeakWeighting

    def GetMzDelta(self, mz: float) -> float: ...

class ExactifySession:  # Class
    def __init__(
        self,
        library: ILibrary,
        exactMassLibrary: ILibrary,
        exParams: Agilent.MassSpectrometry.DataAnalysis.Exactify.ExactifyParams,
        results: Agilent.MassSpectrometry.DataAnalysis.Exactify.LibraryMappingRecord,
        log: Agilent.MassSpectrometry.DataAnalysis.Exactify.ExactifyLog,
    ) -> None: ...
    def Restore(
        self,
        sessionFilePath: str,
        owner: Agilent.MassSpectrometry.DataAnalysis.Exactify.Exactify,
    ) -> None: ...
    def Save(self, sessionFilePath: str) -> None: ...

class FindSpectrumDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(
        self, mainForm: Agilent.MassSpectrometry.DataAnalysis.Exactify.MainForm
    ) -> None: ...

class FragmentFindingAlgorithm(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    ChemSpider: (
        Agilent.MassSpectrometry.DataAnalysis.Exactify.FragmentFindingAlgorithm
    ) = ...  # static # readonly
    FragmentGenerator: (
        Agilent.MassSpectrometry.DataAnalysis.Exactify.FragmentFindingAlgorithm
    ) = ...  # static # readonly

class LibraryChangedDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, exit: bool) -> None: ...

class LibraryMappingRecord:  # Class
    ...

class LibraryProcessedEventArgs(System.EventArgs):  # Class
    ExactMassLibrary: ILibrary  # readonly
    SourceLibrary: ILibrary  # readonly

class LibraryProcessedEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        args: Agilent.MassSpectrometry.DataAnalysis.Exactify.LibraryProcessedEventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(
        self,
        sender: Any,
        args: Agilent.MassSpectrometry.DataAnalysis.Exactify.LibraryProcessedEventArgs,
    ) -> None: ...

class MainForm(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

class MultipleCandidateFragments:  # Class
    CandidateFragmentList: System.Collections.Generic.List[MolecularFormula]  # readonly
    Charge: int  # readonly
    Mass: float  # readonly
    MassRange: float  # readonly
    ParentFormula: MolecularFormula  # readonly
    SelectedFragment: MolecularFormula  # readonly
    SourceMZ: float  # readonly

    def Contains(self, fragment: MolecularFormula) -> bool: ...

class ParametersForm(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

class ProgressDlg(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(
        self,
        parent: Agilent.MassSpectrometry.DataAnalysis.Exactify.MainForm,
        exactify: Agilent.MassSpectrometry.DataAnalysis.Exactify.Exactify,
        numSpectra: int,
    ) -> None: ...

class SpectrumMappingRecord:  # Class
    CompoundFormula: MolecularFormula  # readonly
    NumProcessedPeaks: int  # readonly
    SpectrumRow: LibraryDataSet.SpectrumRow  # readonly

    def GetMappedExactMzValues(self) -> System.Collections.Generic.List[float]: ...
    def GetMappedSourceMzValues(self) -> System.Collections.Generic.List[float]: ...
    def GetPeakMappingRecordByExactMz(
        self, exactMz: float
    ) -> Agilent.MassSpectrometry.DataAnalysis.Exactify.SpectrumPeakMappingRecord: ...
    def GetPeakMappingRecords(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Exactify.SpectrumPeakMappingRecord
    ]: ...
    def GetPeakMappingRecord(
        self, mz: float
    ) -> Agilent.MassSpectrometry.DataAnalysis.Exactify.SpectrumPeakMappingRecord: ...

class SpectrumPeakMappingRecord:  # Class
    AutoSelectedExactMassIon: (
        Agilent.MassSpectrometry.DataAnalysis.Exactify.ExactMassIon
    )  # readonly
    ExactMassIon: (
        Agilent.MassSpectrometry.DataAnalysis.Exactify.ExactMassIon
    )  # readonly
    IsManuallySelected: bool  # readonly
    IsMapped: bool  # readonly
    IsMappedToUniqueFragment: bool  # readonly
    MultipleCandidateFragmentsCount: int  # readonly
    NoCandidateFragmentsCount: int  # readonly
    NoFragmentsInRangeCount: int  # readonly
    PeakDeleted: bool
    SourceMZ: float  # readonly
    SpectrumMappingRecord: (
        Agilent.MassSpectrometry.DataAnalysis.Exactify.SpectrumMappingRecord
    )  # readonly

    def GetCandidateFragments(
        self, charge: int
    ) -> System.Collections.Generic.List[MolecularFormula]: ...
    def GetMultipleCandidateFragments(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Exactify.MultipleCandidateFragments
    ]: ...

class SpectrumPeakWeighting(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    EqualWeight: (
        Agilent.MassSpectrometry.DataAnalysis.Exactify.SpectrumPeakWeighting
    ) = ...  # static # readonly
    Mass: Agilent.MassSpectrometry.DataAnalysis.Exactify.SpectrumPeakWeighting = (
        ...
    )  # static # readonly
    Mass2: Agilent.MassSpectrometry.DataAnalysis.Exactify.SpectrumPeakWeighting = (
        ...
    )  # static # readonly
    Mass3: Agilent.MassSpectrometry.DataAnalysis.Exactify.SpectrumPeakWeighting = (
        ...
    )  # static # readonly

class SpectrumProcessedEventArgs(System.EventArgs):  # Class
    SpectrumIndex: int  # readonly
    SpectrumRow: LibraryDataSet.SpectrumRow  # readonly

class SpectrumProcessedEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        args: Agilent.MassSpectrometry.DataAnalysis.Exactify.SpectrumProcessedEventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(
        self,
        sender: Any,
        args: Agilent.MassSpectrometry.DataAnalysis.Exactify.SpectrumProcessedEventArgs,
    ) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Compliance import ICompliance
from .QueuedTask import IQueuedTask, IQueuedTaskAction, IQueuedTaskContext, TaskPriority
from .ReportMethod import ReportMethodDataSet
from .ReportScript import GraphicsRange, IFixedGraphics

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodRun

class CommandLine:  # Class
    def __init__(self) -> None: ...

    AccountName: str
    ApplicationType: str
    BatchFile: str
    BatchPath: str
    CancelEventName: str
    CompoundIds: str
    ConnectionTicket: str
    Culture: str
    Domain: str
    EncryptedPassword: str
    Help: bool
    LogFile: str
    Method: str
    OutputPath: str
    Parameters: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodRun.MethodRunParameters
    )  # readonly
    Password: str
    Queue: bool
    ReporterName: str
    SampleIds: str
    Server: str
    User: str

    def Run(self) -> None: ...

class ErrorCode(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    ERR_ABORT: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodRun.ErrorCode
    ) = ...  # static # readonly
    ERR_COMMANDLINE: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodRun.ErrorCode
    ) = ...  # static # readonly
    ERR_COMPLIANCE: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodRun.ErrorCode
    ) = ...  # static # readonly
    ERR_INVALID_CULTURE: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodRun.ErrorCode
    ) = ...  # static # readonly
    ERR_PROCESS: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodRun.ErrorCode
    ) = ...  # static # readonly
    NOERROR: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodRun.ErrorCode
    ) = ...  # static # readonly

class FixedGraphics(IFixedGraphics):  # Class
    def __init__(self, dataset: ReportMethodDataSet, reportID: int) -> None: ...
    def GetSampleRangeX(self, sampleName: str) -> Optional[GraphicsRange]: ...
    def GetSampleRangeY(self, sampleName: str) -> Optional[GraphicsRange]: ...
    def GetCompoundRangeMz(self, compoundName: str) -> Optional[GraphicsRange]: ...
    def GetCompoundRangeX(self, compoundName: str) -> Optional[GraphicsRange]: ...
    def GetCompoundRangeY(self, compoundName: str) -> Optional[GraphicsRange]: ...

class IReportMethodTask(
    IQueuedTask, System.Xml.Serialization.IXmlSerializable, System.IDisposable
):  # Interface
    ApplicationType: str
    BatchFile: str
    BatchPath: str
    CompoundIds: List[int]
    Culture: str
    MethodPath: str
    OutputPath: str
    ReporterName: str
    SampleIds: List[int]

class MethodRunParameters:  # Class
    def __init__(self) -> None: ...

    ApplicationType: str
    BatchFile: str
    BatchPath: str
    CancelEventName: str
    CompoundIds: List[int]
    Context: IQueuedTaskContext
    Culture: str
    Method: str
    OutputPath: str
    Priority: TaskPriority
    ReporterName: str
    SampleIds: List[int]

class ProcessPrePost(System.IDisposable):  # Class
    def __init__(
        self,
        outputFolder: str,
        row: ReportMethodDataSet.PrePostProcessRow,
        compliance: ICompliance,
    ) -> None: ...
    def Process(self, formatting: ReportMethodDataSet.FormattingRow) -> None: ...
    def Dispose(self) -> None: ...

class ProcessReportBuilder(System.IDisposable):  # Class
    def Dispose(self) -> None: ...

class ReportMethodTask(
    System.Xml.Serialization.IXmlSerializable,
    System.IDisposable,
    IQueuedTask,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodRun.IReportMethodTask,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        parameters: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodRun.MethodRunParameters,
    ) -> None: ...

    Actions: List[IQueuedTaskAction]  # readonly
    ApplicationType: str
    BatchFile: str
    BatchPath: str
    CancelEventName: str
    CompoundIds: List[int]
    Context: IQueuedTaskContext
    Culture: str
    MethodPath: str
    OutputPath: str
    ProcessingPriority: TaskPriority
    ReporterName: str
    SampleIds: List[int]
    TaskDescription: str  # readonly
    TaskLockName: str  # readonly
    TaskName: str  # readonly

    def Process(self) -> None: ...
    def GetSchema(self) -> System.Xml.Schema.XmlSchema: ...
    def WriteXml(self, writer: System.Xml.XmlWriter) -> None: ...
    def Dispose(self) -> None: ...
    def ReadXml(self, reader: System.Xml.XmlReader) -> None: ...

class Runner(System.MarshalByRefObject):  # Class
    def __init__(self) -> None: ...

    FilesToClean: List[str]  # readonly

    def Run(self, args: List[str]) -> int: ...
    def SetDebugEngine(self, engine: System.MarshalByRefObject) -> None: ...
    def InitializeLifetimeService(self) -> Any: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: DataFitX3

class CubicInformation:  # Class
    Interval: int  # readonly
    LowerBound: float  # readonly
    UpperBound: float  # readonly
    a: float  # readonly
    b: float  # readonly
    c: float  # readonly
    d: float  # readonly

class CubicSpline:  # Class
    def __init__(self) -> None: ...

    IsSolved: bool  # readonly
    LastSolveError: str  # readonly
    NumIntervals: int  # readonly
    NumObservations: int  # readonly
    ResultTables: DataFitX3.DataCollection  # readonly
    Tag: str

    def ReadSolution(self, FilePath: str) -> None: ...
    def CalculateIntegral(self, XLowerBound: float, XUpperBound: float) -> float: ...
    def SaveLog(self, FilePath: str, Append: bool = ...) -> None: ...
    def CalculateDerivative(self, XValue: float) -> float: ...
    def Fit(self, XObservations: List[float], YObservations: List[float]) -> None: ...
    def ClearFit(self) -> None: ...
    def SaveSolution(self, FilePath: str) -> None: ...
    def CalculateRootsAlt(
        self,
        YValue: float,
        XLowerBound: float,
        XUpperBound: float,
        NumIntervals: int = ...,
    ) -> Any: ...
    def PredictValue(self, XValue: float) -> float: ...
    def CalculateRoots(
        self,
        YValue: float,
        XLowerBound: float,
        XUpperBound: float,
        NumIntervals: int = ...,
    ) -> List[float]: ...
    def FitAlt(self, XObservations: Any, YObservations: Any) -> None: ...
    def SaveDFT(self, FilePath: str, MajorVersion: int, MinorVersion: int) -> None: ...
    def GetCubicByInterval(self, Interval: int) -> DataFitX3.CubicInformation: ...
    def PredictArrayAlt(self, XValues: Any) -> Any: ...
    def GetCubicByValue(self, XValue: float) -> DataFitX3.CubicInformation: ...
    def PredictArray(self, XValues: List[float]) -> List[float]: ...
    def FitCollection(self, ObservedData: DataFitX3.DataCollection) -> None: ...

    SolutionComplete: DataFitX3.CubicSpline.SolutionCompleteEventHandler  # Event

    # Nested Types

    class SolutionCompleteEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, TargetObject: Any, TargetMethod: System.IntPtr) -> None: ...
        def EndInvoke(self, DelegateAsyncResult: System.IAsyncResult) -> None: ...
        def BeginInvoke(
            self,
            Success: bool,
            DelegateCallback: System.AsyncCallback,
            DelegateAsyncState: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(self, Success: bool) -> None: ...

class DataCollection(Iterable[Any]):  # Class
    def __init__(self) -> None: ...

    Count: int  # readonly
    IsReadOnly: bool  # readonly
    def __getitem__(self, SeriesIndex: Any) -> DataFitX3.DataSeries: ...
    NumObservationsMax: int  # readonly
    NumObservationsMin: int  # readonly

    def GetEnumerator(self) -> Iterator[Any]: ...
    def Sort(self, SortDirection: DataFitX3.SortTypeEnum = ...) -> None: ...
    def ImportSeriesFromFile(
        self,
        FilePath: str,
        NameArray: List[str],
        Delimiter: DataFitX3.DelimiterTypeEnum = ...,
        DecimalSeparator: str = ...,
        DateSeparator: str = ...,
        MissingQualifier: str = ...,
    ) -> None: ...
    def SetNumberDisplayFormats(self, FormatString: str) -> None: ...
    def ExportSeriesToArrayAlt(self) -> Any: ...
    def SortOnSeries(
        self, SeriesIndex: Any, SortDirection: DataFitX3.SortTypeEnum = ...
    ) -> None: ...
    def ImportNamedSeriesFromFile(
        self,
        FilePath: str,
        Delimiter: DataFitX3.DelimiterTypeEnum = ...,
        DecimalSeparator: str = ...,
        DateSeparator: str = ...,
        MissingQualifier: str = ...,
    ) -> None: ...
    def RemoveSeries(self, SeriesIndex: Any = ...) -> None: ...
    def RemoveAllSeries(self) -> None: ...
    def PruneOnSeries(
        self, SeriesIndex: Any, Value: float, LogicalOperator: DataFitX3.LogicalTypeEnum
    ) -> None: ...
    def AddSeries(
        self, Name: str, PreAllocation: int = ...
    ) -> DataFitX3.DataSeries: ...
    def Prune(
        self, Value: float, LogicalOperator: DataFitX3.LogicalTypeEnum
    ) -> None: ...
    def ExportSeriesToArray(self) -> System.Array[float]: ...
    def CalculateCorrelation(self, SeriesIndex1: Any, SeriesIndex2: Any) -> float: ...
    def ExportSeriesToFile(
        self,
        FilePath: str,
        IncludeNames: bool = ...,
        SaveFormatted: bool = ...,
        AppendData: bool = ...,
    ) -> None: ...
    def ImportSeriesFromFileAlt(
        self,
        FilePath: str,
        NameArray: Any,
        Delimiter: DataFitX3.DelimiterTypeEnum = ...,
        DecimalSeparator: str = ...,
        DateSeparator: str = ...,
        MissingQualifier: str = ...,
    ) -> None: ...
    def ClearRegressionKeys(self) -> None: ...
    def ImportSeriesFromArray(
        self, DataArray: System.Array[float], NameArray: List[str]
    ) -> None: ...
    def ImportSeriesFromArrayAlt(self, DataArray: Any, NameArray: Any) -> None: ...
    def CalculateCovariance(self, SeriesIndex1: Any, SeriesIndex2: Any) -> float: ...

class DataSeries:  # Class
    IsReadOnly: bool  # readonly
    Kurtosis: float  # readonly
    Maximum: float  # readonly
    Mean: float  # readonly
    MeanAbsoluteDeviation: float  # readonly
    MeanSquareDeviation: float  # readonly
    Median: float  # readonly
    Minimum: float  # readonly
    Name: str  # readonly
    NumObservations: int  # readonly
    NumberDisplayFormat: str
    Range: float  # readonly
    RegressionKey: str
    RootMeanSquare: float  # readonly
    Skewness: float  # readonly
    StandardDeviation: float  # readonly
    Sum: float  # readonly
    SumOfSquaredDeviation: float  # readonly
    Tag: str
    Variance: float  # readonly

    def AddObservation(self, Value: float) -> None: ...
    def Sort(self, SortDirection: DataFitX3.SortTypeEnum = ...) -> None: ...
    def ExportToArray(self) -> List[float]: ...
    def Multiply(self, Factor: float) -> None: ...
    def SetObservation(self, ObservationIndex: int, Value: float) -> None: ...
    def ImportFromArrayAlt(self, DataArray: Any, AppendData: bool = ...) -> None: ...
    def GetObservation(self, ObservationIndex: int) -> float: ...
    def RemoveAllObservations(self) -> None: ...
    def ExportToFile(
        self,
        FilePath: str,
        IncludeName: bool = ...,
        SaveFormatted: bool = ...,
        AppendData: bool = ...,
    ) -> None: ...
    def Prune(
        self, Value: float, LogicalOperator: DataFitX3.LogicalTypeEnum
    ) -> None: ...
    def ImportFromFile(
        self,
        FilePath: str,
        AppendData: bool = ...,
        DecimalSeparator: str = ...,
        DateSeparator: str = ...,
    ) -> None: ...
    def GetObservationFormatted(self, ObservationIndex: int) -> str: ...
    def Transform(self, Transformation: DataFitX3.TransformTypeEnum) -> None: ...
    def GetObservationIndex(
        self, SearchType: DataFitX3.SearchTypeEnum, SearchValue: float = ...
    ) -> int: ...
    def Translate(self, Factor: float) -> None: ...
    def RemoveObservation(self, ObservationIndex: int = ...) -> None: ...
    def ExportToArrayAlt(self) -> Any: ...
    def ImportFromArray(
        self, DataArray: List[float], AppendData: bool = ...
    ) -> None: ...
    def Fill(
        self,
        StartValue: float,
        Increment: float,
        NumObservations: int,
        AppendData: bool = ...,
    ) -> None: ...

class DelimiterTypeEnum(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    dfxDelimiterComma: DataFitX3.DelimiterTypeEnum = ...  # static # readonly
    dfxDelimiterSemicolon: DataFitX3.DelimiterTypeEnum = ...  # static # readonly
    dfxDelimiterSpace: DataFitX3.DelimiterTypeEnum = ...  # static # readonly
    dfxDelimiterTab: DataFitX3.DelimiterTypeEnum = ...  # static # readonly

class EstimateTypeEnum(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    dfxEstimateAdjust: DataFitX3.EstimateTypeEnum = ...  # static # readonly
    dfxEstimateConstant: DataFitX3.EstimateTypeEnum = ...  # static # readonly

class Expression:  # Class
    def __init__(self) -> None: ...

    ExpressionDefinition: DataFitX3.ModelDefinition  # readonly
    ExpressionDefinitionLocal: DataFitX3.ModelDefinition  # readonly
    ExpressionParameters: DataFitX3.ExpressionParameters  # readonly
    IsValidExpression: bool  # readonly
    Tag: str

    def DefineExpression(
        self,
        Definition: str,
        Locale: DataFitX3.InputLocaleEnum = ...,
        Description: str = ...,
    ) -> None: ...
    def DefineExpressionSub(
        self,
        Definition: DataFitX3.ModelDefinition,
        Locale: DataFitX3.InputLocaleEnum = ...,
    ) -> None: ...
    def CalculateArrayAlt(self, ParameterIndex: Any, Values: Any) -> Any: ...
    def CalculateArray(
        self, ParameterIndex: Any, Values: List[float]
    ) -> List[float]: ...
    def CalculateValue(self) -> float: ...

class ExpressionParameter:  # Class
    Name: str  # readonly
    Value: float

class ExpressionParameters(Iterable[Any]):  # Class
    Count: int  # readonly
    def __getitem__(self, ParameterIndex: Any) -> DataFitX3.ExpressionParameter: ...
    def GetEnumerator(self) -> Iterator[Any]: ...

class General(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    dfxLast: DataFitX3.General = ...  # static # readonly

class InputLocaleEnum(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    dfxLocaleEnglish: DataFitX3.InputLocaleEnum = ...  # static # readonly
    dfxLocaleLocal: DataFitX3.InputLocaleEnum = ...  # static # readonly

class LogicalTypeEnum(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    dfxLogicalEqualTo: DataFitX3.LogicalTypeEnum = ...  # static # readonly
    dfxLogicalGreaterThan: DataFitX3.LogicalTypeEnum = ...  # static # readonly
    dfxLogicalGreaterThanOrEqualTo: DataFitX3.LogicalTypeEnum = ...  # static # readonly
    dfxLogicalLessThan: DataFitX3.LogicalTypeEnum = ...  # static # readonly
    dfxLogicalLessThanOrEqualTo: DataFitX3.LogicalTypeEnum = ...  # static # readonly

class ModelDefinition:  # Class
    def __init__(self) -> None: ...

    Description: str
    F1: str
    F2: str
    F3: str
    F4: str
    F5: str
    F6: str
    F7: str
    F8: str
    F9: str
    Y: str

class ModelTypeEnum(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    dfxModelExternal: DataFitX3.ModelTypeEnum = ...  # static # readonly
    dfxModelInternal: DataFitX3.ModelTypeEnum = ...  # static # readonly
    dfxModelUser: DataFitX3.ModelTypeEnum = ...  # static # readonly

class MultipleNonlinearRegression:  # Class
    def __init__(self) -> None: ...

    DOFError: int  # readonly
    DOFRegression: int  # readonly
    DOFTotal: int  # readonly
    DurbinWatson: float  # readonly
    IsSolved: bool  # readonly
    IsValidModel: bool  # readonly
    IsWeighted: bool  # readonly
    LastSolveError: str  # readonly
    MaxIterations: int
    MaxUnchangedIterations: int
    ModelDefinition: DataFitX3.ModelDefinition  # readonly
    ModelDefinitionLocal: DataFitX3.ModelDefinition  # readonly
    ModelType: DataFitX3.ModelTypeEnum  # readonly
    NumIndependentVariables: int  # readonly
    NumIterations: int  # readonly
    NumObservations: int  # readonly
    NumUnchangedIterations: int  # readonly
    ProbF: float  # readonly
    R2: float  # readonly
    R2Adjust: float  # readonly
    RegressionParameters: DataFitX3.RegressionParameters  # readonly
    RegressionTolerance: float
    ResidualAverage: float  # readonly
    ResidualSum: float  # readonly
    ResultTables: DataFitX3.DataCollection  # readonly
    SSE: float  # readonly
    SSENorm: float  # readonly
    SSR: float  # readonly
    SST: float  # readonly
    StandardError: float  # readonly
    Tag: str

    def DefineExternalModel(
        self,
        NumIndependentVars: int,
        Parameters: List[str],
        ExternalDerivatives: bool = ...,
    ) -> None: ...
    def CalculateRootsAlt(
        self,
        YValue: float,
        XValues: Any,
        XIndex: int,
        XLowerBound: float,
        XUpperBound: float,
        NumIntervals: int = ...,
    ) -> Any: ...
    def DefineUserModelSub(
        self,
        Definition: DataFitX3.ModelDefinition,
        Locale: DataFitX3.InputLocaleEnum = ...,
    ) -> None: ...
    def PredictArray(self, XValues: System.Array[float]) -> List[float]: ...
    def ReadSolution(self, FilePath: str) -> None: ...
    def SaveSolution(self, FilePath: str) -> None: ...
    def FitCollection(self, ObservedData: DataFitX3.DataCollection) -> None: ...
    def SaveDFT(self, FilePath: str, MajorVersion: int, MinorVersion: int) -> None: ...
    def Fit(
        self, XObservations: System.Array[float], YObservations: List[float]
    ) -> None: ...
    def PredictArrayAlt(self, XValues: Any) -> Any: ...
    def DefineUserModel(
        self,
        Definition: str,
        Locale: DataFitX3.InputLocaleEnum = ...,
        Description: str = ...,
    ) -> None: ...
    def FitAlt(self, XObservations: Any, YObservations: Any) -> None: ...
    def CalculateDerivativeAlt(self, XValues: Any, XIndex: int) -> float: ...
    def SaveLog(self, FilePath: str, Append: bool = ...) -> None: ...
    def PredictValueAlt(self, XValues: Any) -> float: ...
    def DefineInternalModel(self, ModelID: int) -> None: ...
    def ClearFit(self) -> None: ...
    def CalculateRoots(
        self,
        YValue: float,
        XValues: List[float],
        XIndex: int,
        XLowerBound: float,
        XUpperBound: float,
        NumIntervals: int = ...,
    ) -> List[float]: ...
    def FitWeightedAlt(
        self, XObservations: Any, YObservations: Any, StandardDeviations: Any
    ) -> None: ...
    def PredictValue(self, XValues: List[float]) -> float: ...
    def FitWeighted(
        self,
        XObservations: System.Array[float],
        YObservations: List[float],
        StandardDeviations: List[float],
    ) -> None: ...
    def CalculateDerivative(self, XValues: List[float], XIndex: int) -> float: ...
    def DefineExternalModelAlt(
        self, NumIndependentVars: int, Parameters: Any, ExternalDerivatives: bool = ...
    ) -> None: ...

    DerivativeExternal: (
        DataFitX3.MultipleNonlinearRegression.DerivativeExternalEventHandler
    )  # Event
    DerivativeExternalAlt: (
        DataFitX3.MultipleNonlinearRegression.DerivativeExternalAltEventHandler
    )  # Event
    EvaluateExternal: (
        DataFitX3.MultipleNonlinearRegression.EvaluateExternalEventHandler
    )  # Event
    EvaluateExternalAlt: (
        DataFitX3.MultipleNonlinearRegression.EvaluateExternalAltEventHandler
    )  # Event
    IterationComplete: (
        DataFitX3.MultipleNonlinearRegression.IterationCompleteEventHandler
    )  # Event
    SolutionComplete: (
        DataFitX3.MultipleNonlinearRegression.SolutionCompleteEventHandler
    )  # Event

    # Nested Types

    class DerivativeExternalAltEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, TargetObject: Any, TargetMethod: System.IntPtr) -> None: ...
        def EndInvoke(
            self,
            ParameterValues: Any,
            XValues: Any,
            dParameterValues: Any,
            Success: bool,
            DelegateAsyncResult: System.IAsyncResult,
        ) -> None: ...
        def BeginInvoke(
            self,
            ParameterValues: Any,
            XValues: Any,
            dParameterValues: Any,
            Success: bool,
            DelegateCallback: System.AsyncCallback,
            DelegateAsyncState: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self,
            ParameterValues: Any,
            XValues: Any,
            dParameterValues: Any,
            Success: bool,
        ) -> None: ...

    class DerivativeExternalEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, TargetObject: Any, TargetMethod: System.IntPtr) -> None: ...
        def EndInvoke(
            self,
            ParameterValues: System.Array,
            XValues: System.Array,
            dParameterValues: System.Array,
            Success: bool,
            DelegateAsyncResult: System.IAsyncResult,
        ) -> None: ...
        def BeginInvoke(
            self,
            ParameterValues: System.Array,
            XValues: System.Array,
            dParameterValues: System.Array,
            Success: bool,
            DelegateCallback: System.AsyncCallback,
            DelegateAsyncState: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self,
            ParameterValues: System.Array,
            XValues: System.Array,
            dParameterValues: System.Array,
            Success: bool,
        ) -> None: ...

    class EvaluateExternalAltEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, TargetObject: Any, TargetMethod: System.IntPtr) -> None: ...
        def EndInvoke(
            self,
            ParameterValues: Any,
            XValues: Any,
            Result: float,
            Success: bool,
            DelegateAsyncResult: System.IAsyncResult,
        ) -> None: ...
        def BeginInvoke(
            self,
            ParameterValues: Any,
            XValues: Any,
            Result: float,
            Success: bool,
            DelegateCallback: System.AsyncCallback,
            DelegateAsyncState: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self, ParameterValues: Any, XValues: Any, Result: float, Success: bool
        ) -> None: ...

    class EvaluateExternalEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, TargetObject: Any, TargetMethod: System.IntPtr) -> None: ...
        def EndInvoke(
            self,
            ParameterValues: System.Array,
            XValues: System.Array,
            Result: float,
            Success: bool,
            DelegateAsyncResult: System.IAsyncResult,
        ) -> None: ...
        def BeginInvoke(
            self,
            ParameterValues: System.Array,
            XValues: System.Array,
            Result: float,
            Success: bool,
            DelegateCallback: System.AsyncCallback,
            DelegateAsyncState: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self,
            ParameterValues: System.Array,
            XValues: System.Array,
            Result: float,
            Success: bool,
        ) -> None: ...

    class IterationCompleteEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, TargetObject: Any, TargetMethod: System.IntPtr) -> None: ...
        def EndInvoke(
            self, Abort: bool, DelegateAsyncResult: System.IAsyncResult
        ) -> None: ...
        def BeginInvoke(
            self,
            Iteration: int,
            SSE: float,
            Abort: bool,
            DelegateCallback: System.AsyncCallback,
            DelegateAsyncState: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(self, Iteration: int, SSE: float, Abort: bool) -> None: ...

    class SolutionCompleteEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, TargetObject: Any, TargetMethod: System.IntPtr) -> None: ...
        def EndInvoke(self, DelegateAsyncResult: System.IAsyncResult) -> None: ...
        def BeginInvoke(
            self,
            Success: bool,
            DelegateCallback: System.AsyncCallback,
            DelegateAsyncState: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(self, Success: bool) -> None: ...

class NonlinearRegression:  # Class
    def __init__(self) -> None: ...

    DOFError: int  # readonly
    DOFRegression: int  # readonly
    DOFTotal: int  # readonly
    DurbinWatson: float  # readonly
    IsSolved: bool  # readonly
    IsValidModel: bool  # readonly
    IsWeighted: bool  # readonly
    LastSolveError: str  # readonly
    MaxIterations: int
    MaxUnchangedIterations: int
    ModelDefinition: DataFitX3.ModelDefinition  # readonly
    ModelDefinitionLocal: DataFitX3.ModelDefinition  # readonly
    ModelType: DataFitX3.ModelTypeEnum  # readonly
    NumIndependentVariables: int  # readonly
    NumIterations: int  # readonly
    NumObservations: int  # readonly
    NumUnchangedIterations: int  # readonly
    ProbF: float  # readonly
    R2: float  # readonly
    R2Adjust: float  # readonly
    RegressionParameters: DataFitX3.RegressionParameters  # readonly
    RegressionTolerance: float
    ResidualAverage: float  # readonly
    ResidualSum: float  # readonly
    ResultTables: DataFitX3.DataCollection  # readonly
    SSE: float  # readonly
    SSENorm: float  # readonly
    SSR: float  # readonly
    SST: float  # readonly
    StandardError: float  # readonly
    Tag: str

    def DefineExternalModel(
        self, Parameters: List[str], ExternalDerivatives: bool = ...
    ) -> None: ...
    def CalculateRootsAlt(
        self,
        YValue: float,
        XLowerBound: float,
        XUpperBound: float,
        NumIntervals: int = ...,
    ) -> Any: ...
    def DefineUserModelSub(
        self,
        Definition: DataFitX3.ModelDefinition,
        Locale: DataFitX3.InputLocaleEnum = ...,
    ) -> None: ...
    def PredictArray(self, XValues: List[float]) -> List[float]: ...
    def ReadSolution(self, FilePath: str) -> None: ...
    def SaveSolution(self, FilePath: str) -> None: ...
    def FitCollection(self, ObservedData: DataFitX3.DataCollection) -> None: ...
    def SaveDFT(self, FilePath: str, MajorVersion: int, MinorVersion: int) -> None: ...
    def Fit(self, XObservations: List[float], YObservations: List[float]) -> None: ...
    def PredictArrayAlt(self, XValues: Any) -> Any: ...
    def DefineUserModel(
        self,
        Definition: str,
        Locale: DataFitX3.InputLocaleEnum = ...,
        Description: str = ...,
    ) -> None: ...
    def FitAlt(self, XObservations: Any, YObservations: Any) -> None: ...
    def SaveLog(self, FilePath: str, Append: bool = ...) -> None: ...
    def DefineInternalModel(self, ModelID: int) -> None: ...
    def ClearFit(self) -> None: ...
    def CalculateRoots(
        self,
        YValue: float,
        XLowerBound: float,
        XUpperBound: float,
        NumIntervals: int = ...,
    ) -> List[float]: ...
    def CalculateIntegral(self, XLowerBound: float, XUpperBound: float) -> float: ...
    def FitWeightedAlt(
        self, XObservations: Any, YObservations: Any, StandardDeviations: Any
    ) -> None: ...
    def PredictValue(self, XValue: float) -> float: ...
    def FitWeighted(
        self,
        XObservations: List[float],
        YObservations: List[float],
        StandardDeviations: List[float],
    ) -> None: ...
    def CalculateDerivative(self, XValue: float) -> float: ...
    def DefineExternalModelAlt(
        self, Parameters: Any, ExternalDerivatives: bool = ...
    ) -> None: ...

    DerivativeExternal: (
        DataFitX3.NonlinearRegression.DerivativeExternalEventHandler
    )  # Event
    DerivativeExternalAlt: (
        DataFitX3.NonlinearRegression.DerivativeExternalAltEventHandler
    )  # Event
    EvaluateExternal: (
        DataFitX3.NonlinearRegression.EvaluateExternalEventHandler
    )  # Event
    EvaluateExternalAlt: (
        DataFitX3.NonlinearRegression.EvaluateExternalAltEventHandler
    )  # Event
    IterationComplete: (
        DataFitX3.NonlinearRegression.IterationCompleteEventHandler
    )  # Event
    SolutionComplete: (
        DataFitX3.NonlinearRegression.SolutionCompleteEventHandler
    )  # Event

    # Nested Types

    class DerivativeExternalAltEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, TargetObject: Any, TargetMethod: System.IntPtr) -> None: ...
        def EndInvoke(
            self,
            ParameterValues: Any,
            dParameterValues: Any,
            Success: bool,
            DelegateAsyncResult: System.IAsyncResult,
        ) -> None: ...
        def BeginInvoke(
            self,
            ParameterValues: Any,
            XValue: float,
            dParameterValues: Any,
            Success: bool,
            DelegateCallback: System.AsyncCallback,
            DelegateAsyncState: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self,
            ParameterValues: Any,
            XValue: float,
            dParameterValues: Any,
            Success: bool,
        ) -> None: ...

    class DerivativeExternalEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, TargetObject: Any, TargetMethod: System.IntPtr) -> None: ...
        def EndInvoke(
            self,
            ParameterValues: System.Array,
            dParameterValues: System.Array,
            Success: bool,
            DelegateAsyncResult: System.IAsyncResult,
        ) -> None: ...
        def BeginInvoke(
            self,
            ParameterValues: System.Array,
            XValue: float,
            dParameterValues: System.Array,
            Success: bool,
            DelegateCallback: System.AsyncCallback,
            DelegateAsyncState: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self,
            ParameterValues: System.Array,
            XValue: float,
            dParameterValues: System.Array,
            Success: bool,
        ) -> None: ...

    class EvaluateExternalAltEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, TargetObject: Any, TargetMethod: System.IntPtr) -> None: ...
        def EndInvoke(
            self,
            ParameterValues: Any,
            Result: float,
            Success: bool,
            DelegateAsyncResult: System.IAsyncResult,
        ) -> None: ...
        def BeginInvoke(
            self,
            ParameterValues: Any,
            XValue: float,
            Result: float,
            Success: bool,
            DelegateCallback: System.AsyncCallback,
            DelegateAsyncState: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self, ParameterValues: Any, XValue: float, Result: float, Success: bool
        ) -> None: ...

    class EvaluateExternalEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, TargetObject: Any, TargetMethod: System.IntPtr) -> None: ...
        def EndInvoke(
            self,
            ParameterValues: System.Array,
            Result: float,
            Success: bool,
            DelegateAsyncResult: System.IAsyncResult,
        ) -> None: ...
        def BeginInvoke(
            self,
            ParameterValues: System.Array,
            XValue: float,
            Result: float,
            Success: bool,
            DelegateCallback: System.AsyncCallback,
            DelegateAsyncState: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self,
            ParameterValues: System.Array,
            XValue: float,
            Result: float,
            Success: bool,
        ) -> None: ...

    class IterationCompleteEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, TargetObject: Any, TargetMethod: System.IntPtr) -> None: ...
        def EndInvoke(
            self, Abort: bool, DelegateAsyncResult: System.IAsyncResult
        ) -> None: ...
        def BeginInvoke(
            self,
            Iteration: int,
            SSE: float,
            Abort: bool,
            DelegateCallback: System.AsyncCallback,
            DelegateAsyncState: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(self, Iteration: int, SSE: float, Abort: bool) -> None: ...

    class SolutionCompleteEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, TargetObject: Any, TargetMethod: System.IntPtr) -> None: ...
        def EndInvoke(self, DelegateAsyncResult: System.IAsyncResult) -> None: ...
        def BeginInvoke(
            self,
            Success: bool,
            DelegateCallback: System.AsyncCallback,
            DelegateAsyncState: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(self, Success: bool) -> None: ...

class RegressionParameter:  # Class
    InitialEstimate: float
    InitialEstimateType: DataFitX3.EstimateTypeEnum
    Name: str  # readonly
    PreviousValue: float  # readonly
    ProbT: float  # readonly
    StandardError: float  # readonly
    Value: float  # readonly

    def CalculateCIDelta(self, Percent: float) -> float: ...

class RegressionParameters(Iterable[Any]):  # Class
    def __init__(self) -> None: ...

    Count: int  # readonly
    def __getitem__(self, ParameterIndex: Any) -> DataFitX3.RegressionParameter: ...
    def SetDefaultEstimates(self) -> None: ...
    def CalculateCovariance(
        self, ParameterIndex1: Any, ParameterIndex2: Any
    ) -> float: ...
    def GetEnumerator(self) -> Iterator[Any]: ...

class SearchTypeEnum(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    dfxMaximum: DataFitX3.SearchTypeEnum = ...  # static # readonly
    dfxMinimum: DataFitX3.SearchTypeEnum = ...  # static # readonly
    dfxValue: DataFitX3.SearchTypeEnum = ...  # static # readonly

class SortTypeEnum(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    dfxSortAscending: DataFitX3.SortTypeEnum = ...  # static # readonly
    dfxSortDescending: DataFitX3.SortTypeEnum = ...  # static # readonly

class TransformTypeEnum(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    dfxTransformInvert: DataFitX3.TransformTypeEnum = ...  # static # readonly
    dfxTransformInvertNaturalLog: DataFitX3.TransformTypeEnum = ...  # static # readonly
    dfxTransformInvertSquare: DataFitX3.TransformTypeEnum = ...  # static # readonly
    dfxTransformInvertSquareRoot: DataFitX3.TransformTypeEnum = ...  # static # readonly
    dfxTransformNaturalLog: DataFitX3.TransformTypeEnum = ...  # static # readonly
    dfxTransformSquare: DataFitX3.TransformTypeEnum = ...  # static # readonly
    dfxTransformSquareRoot: DataFitX3.TransformTypeEnum = ...  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import AcquisitionMethod, AppCommandContext, MethodSetupSession

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO

class AcqMethodGenerator:  # Class
    def __init__(
        self,
        context: AppCommandContext,
        acqMethod: AcquisitionMethod,
        peaksNotFound: List[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TransitionPeakRow
        ],
    ) -> None: ...

    OptimizedAcqMethodXml: System.Xml.XmlDocument  # readonly
    UnoptimizedAcqMethod: AcquisitionMethod  # readonly

    @overload
    def SaveAcqMethodXml(self, dirPath: str) -> None: ...
    @overload
    def SaveAcqMethodXml(self, dirPath: str, fileName: str) -> None: ...
    def CreateOptimizedAcqMethod(
        self,
        ods: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet,
    ) -> System.Xml.XmlDocument: ...

class AcquiredTransitionTable:  # Class
    PeaksNotFound: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TransitionPeakRow
    ]  # readonly

class AutoSIMParams(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.CompoundListTSOptimizerParams
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        claParams: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.CompoundListTSOptimizerParams,
    ) -> None: ...

    DEFAULT_CYCLES_PER_SECOND: float = ...  # static # readonly
    DEFAULT_MAX_DWELL_TIME: float = ...  # static # readonly
    DEFAULT_MEDIAN_DWELL_TIME: float = ...  # static # readonly
    DEFAULT_MIN_DWELL_TIME: float = ...  # static # readonly
    DEFAULT_USE_CONSTANT_CYCLE_TIME: bool = ...  # static # readonly
    DEFAULT_USE_EQUAL_DWELL_TIMES: bool = ...  # static # readonly
    XML_PARAM_FILE: str = ...  # static # readonly

    MaxDwellTime: float
    MinDwellTime: float

    def UseDefaults(self) -> None: ...
    @overload
    def Write(self) -> None: ...
    @overload
    def Write(self, fileName: str) -> None: ...

class BoundaryCostScale(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Log10_0: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.BoundaryCostScale
    ) = ...  # static # readonly
    Log10_1: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.BoundaryCostScale
    ) = ...  # static # readonly
    Log10_2: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.BoundaryCostScale
    ) = ...  # static # readonly
    Log10_3: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.BoundaryCostScale
    ) = ...  # static # readonly
    Log10_4: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.BoundaryCostScale
    ) = ...  # static # readonly
    Log10_5: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.BoundaryCostScale
    ) = ...  # static # readonly
    Log10_6: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.BoundaryCostScale
    ) = ...  # static # readonly

class CompoundListTSOptimizer:  # Class
    @overload
    def __init__(
        self,
        dataSet: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet,
    ) -> None: ...
    @overload
    def __init__(
        self,
        dataSet: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet,
        userParams: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.CompoundListTSOptimizerParams,
    ) -> None: ...

    MaxTimeSegments: int
    MinPointsPerTimeSegment: int  # readonly
    TransitionTable: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.AcquiredTransitionTable
    )  # readonly

    def RunOptimization(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet
    ): ...
    def RunOptimizationImpl(self) -> None: ...

class CompoundListTSOptimizerParams:  # Class
    def __init__(self) -> None: ...

    DEFAULT_CYCLE_TIME: float = ...  # static # readonly
    DEFAULT_DWELL_TIME: float = ...  # static # readonly

    CyclesPerSecond: float
    DwellTime: float
    EqualDwellTimes: bool
    RemoveDuplicateTransitions: bool
    UseConstantCycleTime: bool

class ExcelInputColumns(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    CE: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.ExcelInputColumns = (
        ...
    )  # static # readonly
    Compound: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.ExcelInputColumns
    ) = ...  # static # readonly
    Dwell: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.ExcelInputColumns = (
        ...
    )  # static # readonly
    FV: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.ExcelInputColumns = (
        ...
    )  # static # readonly
    ISTD: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.ExcelInputColumns = (
        ...
    )  # static # readonly
    MS1_Res: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.ExcelInputColumns
    ) = ...  # static # readonly
    MS2_Res: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.ExcelInputColumns
    ) = ...  # static # readonly
    Polarity: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.ExcelInputColumns
    ) = ...  # static # readonly
    Precursor: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.ExcelInputColumns
    ) = ...  # static # readonly
    Product: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.ExcelInputColumns
    ) = ...  # static # readonly
    RT: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.ExcelInputColumns = (
        ...
    )  # static # readonly
    RTWindow: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.ExcelInputColumns
    ) = ...  # static # readonly
    Reference: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.ExcelInputColumns
    ) = ...  # static # readonly

class ExcelInputDataReader:  # Class
    def __init__(self) -> None: ...

    COLUMN_NAMES: List[str]  # static # readonly

    DataSet: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet
    )  # readonly

    def Read(self, inputFilePath: str, worksheetName: str) -> None: ...

class Function1D(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> float: ...
    def BeginInvoke(
        self, x: float, callback: System.AsyncCallback, object: Any
    ) -> System.IAsyncResult: ...
    def Invoke(self, x: float) -> float: ...

class FunctionGradientND(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        x: List[float],
        df: List[float],
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(self, x: List[float], df: List[float]) -> None: ...

class FunctionND(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> float: ...
    def BeginInvoke(
        self, x: List[float], callback: System.AsyncCallback, object: Any
    ) -> System.IAsyncResult: ...
    def Invoke(self, x: List[float]) -> float: ...

class NDimOptimization:  # Class
    def __init__(
        self,
        func: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.FunctionND,
        dfunc: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.FunctionGradientND,
        nDim: int,
    ) -> None: ...
    def GoldenSectionSearch(
        self,
        func: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.Function1D,
        a: float,
        b: float,
        c: float,
        tolerance: float,
        xmin: float,
    ) -> float: ...
    def MinimizeFunctionAlongLine(
        self,
        f1dim: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.Function1D,
        p: List[float],
        xdir: List[float],
    ) -> float: ...
    def BracketFunctionMinimum(
        self,
        func: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.Function1D,
        a: float,
        b: float,
        c: float,
    ) -> None: ...
    def ConjugateGradientMinimization(
        self, p: List[float], tolerance: float, nIter: int
    ) -> float: ...

class SIMAcqMethodGenerator:  # Class
    def __init__(self) -> None: ...

    AutoSIMDataSet: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet
    )  # readonly
    AutoSIMParams: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.AutoSIMParams
    )  # readonly

    def CreateSIMAcquisitionMethod(
        self,
        acqMethodDirectory: str,
        setupSession: MethodSetupSession,
        options: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.CompoundListTSOptimizerParams,
    ) -> None: ...

class SafetyMarginUnits(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Minutes: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.SafetyMarginUnits
    ) = ...  # static # readonly
    PeakWidths: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.SafetyMarginUnits
    ) = ...  # static # readonly
    Percent: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.SafetyMarginUnits
    ) = ...  # static # readonly

class TimeSegmentBoundary:  # Class
    DEFAULT_COST_SCALE: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.BoundaryCostScale
    ) = ...  # static # readonly
    DEFAULT_SAFETY_MARGIN: float = ...  # static # readonly

    CostScale: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.BoundaryCostScale
    )  # static
    SafetyMargin: float  # static
    SafetyMarginUnits: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.SafetyMarginUnits
    )  # static

class TimeSegmentOptimizer:  # Class
    def __init__(
        self,
        dataSet: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet,
    ) -> None: ...

    DEFAULT_MIN_DWELL_TIME: float = ...  # static # readonly
    DEFAULT_MIN_POINTS_PER_PEAK: int = ...  # static # readonly
    DIAG_DIR: str = ...  # static # readonly
    MAX_TIME_SEGMENTS: int = ...  # static # readonly
    MAX_TRANSITIONS_PER_TS: int = ...  # static # readonly
    MIN_ALLOWED_DWELL_TIME: float = ...  # static # readonly
    MIN_POINTS_PER_TIME_SEGMENT: int = ...  # static # readonly

    MinDwellTime: float
    MinPointsPerPeak: int
    MinPointsPerTimeSegment: int  # readonly
    TransitionTable: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.AcquiredTransitionTable
    )  # readonly

    def IsolateOutliers(self) -> None: ...
    def RunOptimization(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet
    ): ...

class TimeSegmentOptimizerDataSet(
    System.IDisposable,
    System.ComponentModel.ISupportInitializeNotification,
    System.IServiceProvider,
    System.Data.DataSet,
    System.Xml.Serialization.IXmlSerializable,
    System.Runtime.Serialization.ISerializable,
    System.ComponentModel.IListSource,
    System.ComponentModel.ISupportInitialize,
    System.ComponentModel.IComponent,
):  # Class
    def __init__(self) -> None: ...

    IsSIM: bool  # readonly
    Relations: System.Data.DataRelationCollection  # readonly
    SchemaSerializationMode: System.Data.SchemaSerializationMode
    Tables: System.Data.DataTableCollection  # readonly
    TimeSegment: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TimeSegmentDataTable
    )  # readonly
    TransitionPeak: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TransitionPeakDataTable
    )  # readonly

    @staticmethod
    def GetTypedDataSetSchema(
        xs: System.Xml.Schema.XmlSchemaSet,
    ) -> System.Xml.Schema.XmlSchemaComplexType: ...
    def GetUnusedTimeSegmentID(self) -> int: ...
    def Clone(self) -> System.Data.DataSet: ...

    # Nested Types

    class TimeSegmentDataTable(
        System.IServiceProvider,
        System.ComponentModel.ISupportInitialize,
        Iterable[Any],
        System.ComponentModel.ISupportInitializeNotification,
        System.Xml.Serialization.IXmlSerializable,
        System.ComponentModel.IComponent,
        System.Runtime.Serialization.ISerializable,
        Iterable[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TimeSegmentRow
        ],
        System.ComponentModel.IListSource,
        System.Data.TypedTableBase[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TimeSegmentRow
        ],
        System.IDisposable,
    ):  # Class
        def __init__(self) -> None: ...

        Count: int  # readonly
        IndexColumn: System.Data.DataColumn  # readonly
        def __getitem__(
            self, index: int
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TimeSegmentRow
        ): ...
        OptimizationFactorColumn: System.Data.DataColumn  # readonly
        OptimizedCycleTimeColumn: System.Data.DataColumn  # readonly
        TimeSegmentIDColumn: System.Data.DataColumn  # readonly
        TransitionCountColumn: System.Data.DataColumn  # readonly
        XEndColumn: System.Data.DataColumn  # readonly
        XStartColumn: System.Data.DataColumn  # readonly

        def RemoveTimeSegmentRow(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TimeSegmentRow,
        ) -> None: ...
        @overload
        def AddTimeSegmentRow(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TimeSegmentRow,
        ) -> None: ...
        @overload
        def AddTimeSegmentRow(
            self,
            TimeSegmentID: int,
            Index: int,
            OptimizationFactor: float,
            OptimizedCycleTime: float,
            TransitionCount: int,
            XEnd: float,
            XStart: float,
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TimeSegmentRow
        ): ...
        @staticmethod
        def GetTypedTableSchema(
            xs: System.Xml.Schema.XmlSchemaSet,
        ) -> System.Xml.Schema.XmlSchemaComplexType: ...
        def NewTimeSegmentRow(
            self,
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TimeSegmentRow
        ): ...
        def FindByTimeSegmentID(
            self, TimeSegmentID: int
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TimeSegmentRow
        ): ...
        def Clone(self) -> System.Data.DataTable: ...

        TimeSegmentRowChanged: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TimeSegmentRowChangeEventHandler
        )  # Event
        TimeSegmentRowChanging: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TimeSegmentRowChangeEventHandler
        )  # Event
        TimeSegmentRowDeleted: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TimeSegmentRowChangeEventHandler
        )  # Event
        TimeSegmentRowDeleting: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TimeSegmentRowChangeEventHandler
        )  # Event

    class TimeSegmentRow(System.Data.DataRow):  # Class
        Index: int
        OptimizationFactor: float
        OptimizedCycleTime: float
        TimeSegmentID: int
        TransitionCount: int
        XEnd: float
        XStart: float

        def SetOptimizedCycleTimeNull(self) -> None: ...
        def IsOptimizationFactorNull(self) -> bool: ...
        def IsXStartNull(self) -> bool: ...
        def SetIndexNull(self) -> None: ...
        def IsIndexNull(self) -> bool: ...
        def SetXEndNull(self) -> None: ...
        def GetTransitionPeakRows(
            self,
        ) -> List[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TransitionPeakRow
        ]: ...
        def IsOptimizedCycleTimeNull(self) -> bool: ...
        def IsTransitionCountNull(self) -> bool: ...
        def SetTransitionCountNull(self) -> None: ...
        def IsXEndNull(self) -> bool: ...
        def SetOptimizationFactorNull(self) -> None: ...
        def SetXStartNull(self) -> None: ...

    class TimeSegmentRowChangeEvent(System.EventArgs):  # Class
        def __init__(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TimeSegmentRow,
            action: System.Data.DataRowAction,
        ) -> None: ...

        Action: System.Data.DataRowAction  # readonly
        Row: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TimeSegmentRow
        )  # readonly

    class TimeSegmentRowChangeEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, object: Any, method: System.IntPtr) -> None: ...
        def EndInvoke(self, result: System.IAsyncResult) -> None: ...
        def BeginInvoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TimeSegmentRowChangeEvent,
            callback: System.AsyncCallback,
            object: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TimeSegmentRowChangeEvent,
        ) -> None: ...

    class TransitionPeakDataTable(
        System.ComponentModel.ISupportInitialize,
        Iterable[Any],
        System.ComponentModel.ISupportInitializeNotification,
        System.Xml.Serialization.IXmlSerializable,
        Iterable[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TransitionPeakRow
        ],
        System.ComponentModel.IComponent,
        System.Runtime.Serialization.ISerializable,
        System.Data.TypedTableBase[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TransitionPeakRow
        ],
        System.ComponentModel.IListSource,
        System.IDisposable,
        System.IServiceProvider,
    ):  # Class
        def __init__(self) -> None: ...

        AbundanceValuesColumn: System.Data.DataColumn  # readonly
        AcquiredDwellTimeColumn: System.Data.DataColumn  # readonly
        AreaColumn: System.Data.DataColumn  # readonly
        CollisionEnergyColumn: System.Data.DataColumn  # readonly
        CompoundNameColumn: System.Data.DataColumn  # readonly
        Count: int  # readonly
        DeltaEMVColumn: System.Data.DataColumn  # readonly
        FragmentorVoltageColumn: System.Data.DataColumn  # readonly
        GainColumn: System.Data.DataColumn  # readonly
        HeightColumn: System.Data.DataColumn  # readonly
        ISTDFlagColumn: System.Data.DataColumn  # readonly
        IonPolarityColumn: System.Data.DataColumn  # readonly
        def __getitem__(
            self, index: int
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TransitionPeakRow
        ): ...
        MZColumn: System.Data.DataColumn  # readonly
        Ms1ResColumn: System.Data.DataColumn  # readonly
        Ms2ResColumn: System.Data.DataColumn  # readonly
        NoiseFactorColumn: System.Data.DataColumn  # readonly
        NumberOfPointsColumn: System.Data.DataColumn  # readonly
        OptimizedDwellTimeColumn: System.Data.DataColumn  # readonly
        OptimizedNumberOfPointsColumn: System.Data.DataColumn  # readonly
        OptimizedRSDColumn: System.Data.DataColumn  # readonly
        OutlierColumn: System.Data.DataColumn  # readonly
        RTValuesColumn: System.Data.DataColumn  # readonly
        RetentionTimeColumn: System.Data.DataColumn  # readonly
        SampleDataPathColumn: System.Data.DataColumn  # readonly
        ScanModeColumn: System.Data.DataColumn  # readonly
        SelectedMZColumn: System.Data.DataColumn  # readonly
        TimeSegmentIDColumn: System.Data.DataColumn  # readonly
        TransitionColumn: System.Data.DataColumn  # readonly
        TransitionPeakIDColumn: System.Data.DataColumn  # readonly
        XEndColumn: System.Data.DataColumn  # readonly
        XStartColumn: System.Data.DataColumn  # readonly

        @staticmethod
        def GetTypedTableSchema(
            xs: System.Xml.Schema.XmlSchemaSet,
        ) -> System.Xml.Schema.XmlSchemaComplexType: ...
        def FindByTimeSegmentIDTransitionPeakID(
            self, TimeSegmentID: int, TransitionPeakID: int
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TransitionPeakRow
        ): ...
        @overload
        def AddTransitionPeakRow(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TransitionPeakRow,
        ) -> None: ...
        @overload
        def AddTransitionPeakRow(
            self,
            parentTimeSegmentRowByFK_TimeSegment_TransitionPeak: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TimeSegmentRow,
            TransitionPeakID: int,
            AbundanceValues: str,
            AcquiredDwellTime: float,
            Area: float,
            CollisionEnergy: float,
            CompoundName: str,
            DeltaEMV: float,
            FragmentorVoltage: float,
            Gain: float,
            Height: float,
            IonPolarity: str,
            ISTDFlag: bool,
            Ms1Res: str,
            Ms2Res: str,
            MZ: float,
            NoiseFactor: float,
            NumberOfPoints: int,
            OptimizedDwellTime: float,
            OptimizedNumberOfPoints: int,
            OptimizedRSD: float,
            Outlier: bool,
            RetentionTime: float,
            RTValues: str,
            SampleDataPath: str,
            ScanMode: str,
            SelectedMZ: float,
            Transition: str,
            XEnd: float,
            XStart: float,
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TransitionPeakRow
        ): ...
        def Clone(self) -> System.Data.DataTable: ...
        def RemoveTransitionPeakRow(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TransitionPeakRow,
        ) -> None: ...
        def NewTransitionPeakRow(
            self,
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TransitionPeakRow
        ): ...

        TransitionPeakRowChanged: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TransitionPeakRowChangeEventHandler
        )  # Event
        TransitionPeakRowChanging: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TransitionPeakRowChangeEventHandler
        )  # Event
        TransitionPeakRowDeleted: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TransitionPeakRowChangeEventHandler
        )  # Event
        TransitionPeakRowDeleting: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TransitionPeakRowChangeEventHandler
        )  # Event

    class TransitionPeakRow(System.Data.DataRow):  # Class
        AbundanceValues: str
        AcquiredDwellTime: float
        Area: float
        CollisionEnergy: float
        CompoundName: str
        DeltaEMV: float
        FragmentorVoltage: float
        Gain: float
        Height: float
        ISTDFlag: bool
        IonPolarity: str
        IsPeakNotFound: bool  # readonly
        MZ: float
        Ms1Res: str
        Ms2Res: str
        NoiseFactor: float
        NumberOfPoints: int
        OptimizedDwellTime: float
        OptimizedNumberOfPoints: int
        OptimizedRSD: float
        Outlier: bool
        RTValues: str
        RetentionTime: float
        SampleDataPath: str
        ScanMode: str
        SelectedMZ: float
        TimeSegmentID: int
        TimeSegmentRow: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TimeSegmentRow
        )
        Transition: str
        TransitionPeakID: int
        XEnd: float
        XStart: float

        def IsMZNull(self) -> bool: ...
        def IsNoiseFactorNull(self) -> bool: ...
        def IsOptimizedRSDNull(self) -> bool: ...
        def SetMs1ResNull(self) -> None: ...
        def IsAbundanceValuesNull(self) -> bool: ...
        def IsRTValuesNull(self) -> bool: ...
        def IsAcquiredDwellTimeNull(self) -> bool: ...
        def SetNumberOfPointsNull(self) -> None: ...
        def IsHeightNull(self) -> bool: ...
        def SetAcquiredDwellTimeNull(self) -> None: ...
        def SetNoiseFactorNull(self) -> None: ...
        def SetScanModeNull(self) -> None: ...
        def SetISTDFlagNull(self) -> None: ...
        def IsAreaNull(self) -> bool: ...
        def SetIonPolarityNull(self) -> None: ...
        def SetAbundanceValuesNull(self) -> None: ...
        def IsMs2ResNull(self) -> bool: ...
        def IsRetentionTimeNull(self) -> bool: ...
        def SetOutlierNull(self) -> None: ...
        def SetRTValuesNull(self) -> None: ...
        def IsFragmentorVoltageNull(self) -> bool: ...
        def SetDeltaEMVNull(self) -> None: ...
        def SetTransitionNull(self) -> None: ...
        def SetFragmentorVoltageNull(self) -> None: ...
        def IsIonPolarityNull(self) -> bool: ...
        def IsGainNull(self) -> bool: ...
        def IsNumberOfPointsNull(self) -> bool: ...
        def SetSampleDataPathNull(self) -> None: ...
        def SetHeightNull(self) -> None: ...
        def SetXEndNull(self) -> None: ...
        def IsSelectedMZNull(self) -> bool: ...
        def IsCollisionEnergyNull(self) -> bool: ...
        def IsOptimizedNumberOfPointsNull(self) -> bool: ...
        def IsOutlierNull(self) -> bool: ...
        def IsScanModeNull(self) -> bool: ...
        def SetOptimizedNumberOfPointsNull(self) -> None: ...
        def SetMs2ResNull(self) -> None: ...
        def IsXStartNull(self) -> bool: ...
        def SetRetentionTimeNull(self) -> None: ...
        def IsDeltaEMVNull(self) -> bool: ...
        def IsCompoundNameNull(self) -> bool: ...
        def SetXStartNull(self) -> None: ...
        def SetGainNull(self) -> None: ...
        def IsSampleDataPathNull(self) -> bool: ...
        def SetMZNull(self) -> None: ...
        def IsMs1ResNull(self) -> bool: ...
        def SetAreaNull(self) -> None: ...
        def SetOptimizedDwellTimeNull(self) -> None: ...
        def SetCollisionEnergyNull(self) -> None: ...
        def SetCompoundNameNull(self) -> None: ...
        def SetOptimizedRSDNull(self) -> None: ...
        def IsISTDFlagNull(self) -> bool: ...
        def IsXEndNull(self) -> bool: ...
        def IsOptimizedDwellTimeNull(self) -> bool: ...
        def IsTransitionNull(self) -> bool: ...
        def SetSelectedMZNull(self) -> None: ...

    class TransitionPeakRowChangeEvent(System.EventArgs):  # Class
        def __init__(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TransitionPeakRow,
            action: System.Data.DataRowAction,
        ) -> None: ...

        Action: System.Data.DataRowAction  # readonly
        Row: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TransitionPeakRow
        )  # readonly

    class TransitionPeakRowChangeEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, object: Any, method: System.IntPtr) -> None: ...
        def EndInvoke(self, result: System.IAsyncResult) -> None: ...
        def BeginInvoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TransitionPeakRowChangeEvent,
            callback: System.AsyncCallback,
            object: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet.TransitionPeakRowChangeEvent,
        ) -> None: ...

class TransitionTableGenerator:  # Class
    def __init__(self, context: AppCommandContext) -> None: ...

    AcqMehod: AcquisitionMethod  # readonly
    DataSet: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TSO.TimeSegmentOptimizerDataSet
    )  # readonly

    def AddTransitionTableFromSample(self, samplePath: str) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Compliance import ICompliance, IDataStorage, ILogonECM
from .ComplianceUI import IComplianceUI
from .DataStorageECM import ComplianceECM, DataStorage

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ECMProxy

class Client(System.IDisposable):  # Class
    def __init__(self) -> None: ...

    server_url: str = ...  # static # readonly

    def Download(
        self,
        onlyIfChecksumNotMatch: bool,
        filePath: str,
        revisionNumber: str,
        folderPath: str,
        recreateDirectoryStructure: bool,
        overwriteWithoutPrompt: bool,
    ) -> bool: ...
    def Dispose(self) -> None: ...
    def Connect(self, serverUrl: str, loginID: str) -> None: ...
    @staticmethod
    def GetServerHost(loginID: str) -> str: ...

class Compliance(
    IComplianceUI, System.IDisposable, ComplianceECM, ICompliance, ILogonECM
):  # Class
    def __init__(self) -> None: ...

class DataStorage(System.IDisposable, IDataStorage):  # Class
    def __init__(
        self,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ECMProxy.Compliance,
    ) -> None: ...
    def InitFolders(self) -> None: ...

class ECMProxyException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Exception,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, ex: System.Exception) -> None: ...
    @overload
    def __init__(self) -> None: ...

    ECMCode: int
    ECMMessage: str

class IServer(object):  # Interface
    def Download(
        self,
        onlyIfChecksumNotMatch: bool,
        filePath: str,
        revisionNumber: str,
        folderPath: str,
        recreateDirectoryStructure: bool,
        overwriteWithoutPrompt: bool,
    ) -> bool: ...
    def Disconnect(self) -> None: ...
    def Login(self, serverUrl: str, loginID: str) -> None: ...
